Stan Math Library: stan::math::index_type< Eigen::Matrix< T, R, C > > Struct Template Reference

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- Class List
- Class Index
- Class Hierarchy
- Class Members

Public Types | List of all members
stan::math::index_type< Eigen::Matrix< T, R, C > > Struct Template Reference

Template metaprogram defining typedef for the type of index for an Eigen matrix, vector, or row vector. More...

`#include <index_type.hpp>`

## Public Types
typedef Eigen::Matrix< T, R, C >::Index | type

## Detailed Description

### template<typename T, int R, int C>
struct stan::math::index_type< Eigen::Matrix< T, R, C > >

Template metaprogram defining typedef for the type of index for an Eigen matrix, vector, or row vector.

Template Parameters

  T | type of matrix.
  R | number of rows for matrix.
  C | number of columns for matrix.

Definition at line 20 of file index_type.hpp.

## Member Typedef Documentation

template<typename T , int R, int C>

typedef Eigen::Matrix<T, R, C>::Index stan::math::index_type< Eigen::Matrix< T, R, C > >::type

Definition at line 21 of file index_type.hpp.

The documentation for this struct was generated from the following file:

- stan/math/prim/mat/meta/index_type.hpp

[ Stan Home Page ] © 2011–2016, Stan Development Team.